Coverage for C:\checkouts\github\OpenQTSim\openqtsim\__init__.py: 100%

# Coverage for C:\checkouts\github\OpenQTSim\openqtsim\__init__.py : 100%

## 11 statements 11 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""Top-level package for queueing."""

2

3 __author__ = "Mark van Koningsveld and Joris den Uijl"

4 __email__ = "m.vankoningsveld@tudelft.nl"

5 __version__ = "0.3.0"

6

7 from .arrival_process import ArrivalProcess

8 from .service_process import ServiceProcess

9

10 from .queue import Queue

11 from .customer import Customer

12 from .simulation import Simulation

13 from .mm1 import MM1

14 from .tables import get_waiting_time_service_time_table

15 from .mt_engine import worker, Task